import respx
from httpx import Response

from statuscheck.services.models.generic import COMPONENT_TYPE_PARTIAL_OUTAGE
from statuscheck.services.salesforce import STATUS_CORE_INCIDENT
from statuscheck.utils import get_statuscheck_api


class TestSalesforce:
    @respx.mock
    def test_incident(self):
        with open("tests/test_services/test_data/salesforce_incident.json", "rb") as f:
            mock_response_body = f.read()
        respx.get(
            "https://api.status.salesforce.com/v1/instances/status/preview",
        ).mock(return_value=Response(200, content=mock_response_body))

        with open(
            "tests/test_services/test_data/salesforce_localizations.json", "rb"
        ) as f:
            mock_response_body = f.read()
        respx.get(
            "https://api.status.salesforce.com/v1/localizations",
        ).mock(return_value=Response(200, content=mock_response_body))

        service_name = "salesforce"
        service_api = get_statuscheck_api(service_name)

        assert service_api._module_name == service_name
        assert service_api.status_url
        assert service_api.service_url
        assert service_api.summary

        assert service_api.summary.status
        assert service_api.summary.incidents
        assert service_api.summary.components

        assert service_api.summary.status.code == STATUS_CORE_INCIDENT
        assert len(service_api.summary.incidents) == 1
        assert len(service_api.summary.components) == 1

        component = service_api.summary.components[0]
        assert component.status == COMPONENT_TYPE_PARTIAL_OUTAGE
